@@ -215,7 +215,7 @@ def calculate_cos_solar_zenith_angle_integrated(
                         ]
                     )
                 else:
-                    print(f"Invalid integration_order {integration_order}")
+                    print("Invalid integration_order %d", integration_order)
                     raise ValueError
 
     assert intervals_per_hour > 0
@@ -227,13 +227,10 @@ def calculate_cos_solar_zenith_angle_integrated(
     time_steps = np.linspace(tbegin, tend, num=nsplits + 1)
 
     integral = np.zeros_like(lat)
-
     for s in range(len(time_steps) - 1):
         ti = time_steps[s]
         tf = time_steps[s + 1]
 
-        # print(f"Interval {s+1} [{ti}, {tf}]")
-
         deltat = tf - ti
         jacob = deltat / 2.0
 
@@ -242,17 +239,12 @@ def calculate_cos_solar_zenith_angle_integrated(
         t = jacob * E
         t += (tf + ti) / 2.0
 
-        # print(f"w {w}")
-        # print(f"t {t}")
-
         for n in range(len(w)):
             cossza = calculate_cos_solar_zenith_angle(
                 lat=lat, lon=lon, y=y, m=m, d=d, h=(h + t[n])
             )
             integral += w[n] * cossza
 
-    # integral /= (tend - tbegin) # average is above for efficiency
-
     return integral
 
 
@@ -298,40 +290,7 @@ def calculate_mean_radiant_temperature(ssrd, ssr, fdir, strd, strr, cossza):
     return mrt
 
 
-def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
-    """
-    UTCI
-    :param t2_k: (float array) is 2m temperature [K]
-    :param va_ms: (float array) is wind speed at 10 meters [m/s]
-    :param mrt_k:(float array) is mean radiant temperature [K]
-    :param e_hPa: (float array) is water vapour pressure [hPa]
-    :param td_k: (float array) is 2m dew point temperature [K]
-
-    Calculate UTCI with a 6th order polynomial approximation according to:
-    Brode, P. et al. Deriving the operational procedure for the
-    Universal Thermal Climate Index (UTCI). Int J Biometeorol (2012) 56: 48.1
-
-    returns UTCI [°C]
-
-    """
-    t2 = __wrap(t2_k)
-    va = __wrap(va_ms)
-    mrt_kw = __wrap(mrt_k)
-
-    if e_hPa is not None:
-        ehPa = __wrap(e_hPa)
-        rh = ehPa / 10.0  # rh in kPa
-    else:
-        if td_k is not None:
-            t2d = __wrap(td_k)
-            rh_pc = calculate_relative_humidity_percent(t2, t2d)
-            ehPa = calculate_saturation_vapour_pressure(t2) * rh_pc / 100.0
-            rh = ehPa / 10.0  # rh in kPa
-        else:
-            raise ValueError("Missing input e_hPa or td_k")
-
-    t2m = kelvin_to_celsius(t2)  # polynomial approx. is in Celsius
-    mrt = kelvin_to_celsius(mrt_kw)  # polynomial approx. is in Celsius
+def calculate_utci_impl(t2m, mrt, va, rh):
 
     e_mrt = np.subtract(mrt, t2m)
 
@@ -359,6 +318,21 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
     rh5 = rh4 * rh
     rh6 = rh5 * rh
 
+    varh2 = va * rh2
+    va2_rh = va2 * rh
+    va2_e_mrt = va2 * e_mrt
+    e_mrt_rh = e_mrt * rh
+    e_mrt_rh2 = e_mrt * rh2
+    e_mrt2_rh = e_mrt2 * rh
+    e_mrt2_rh2 = e_mrt2 * rh2
+    e_mrt_rh3 = e_mrt * rh3
+    va_e_mrt = va * e_mrt
+    va_e_mrt2 = va * e_mrt2
+    va_rh = va * rh
+    t2m_va = t2m * va
+    e_mrt3_rh = e_mrt3 * rh
+    e_mrt4_rh = e_mrt4 * rh
+
     utci = (
         t2m
         + 6.07562052e-01
@@ -395,15 +369,15 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + -7.60781159e-07 * t2m3 * e_mrt
         + 3.77830287e-08 * t2m4 * e_mrt
         + 5.43079673e-10 * t2m5 * e_mrt
-        + -2.00518269e-02 * va * e_mrt
-        + 8.92859837e-04 * t2m * va * e_mrt
-        + 3.45433048e-06 * t2m2 * va * e_mrt
-        + -3.77925774e-07 * t2m3 * va * e_mrt
-        + -1.69699377e-09 * t2m4 * va * e_mrt
-        + 1.69992415e-04 * va2 * e_mrt
-        + -4.99204314e-05 * t2m * va2 * e_mrt
-        + 2.47417178e-07 * t2m2 * va2 * e_mrt
-        + 1.07596466e-08 * t2m3 * va2 * e_mrt
+        + -2.00518269e-02 * va_e_mrt
+        + 8.92859837e-04 * t2m * va_e_mrt
+        + 3.45433048e-06 * t2m2 * va_e_mrt
+        + -3.77925774e-07 * t2m3 * va_e_mrt
+        + -1.69699377e-09 * t2m4 * va_e_mrt
+        + 1.69992415e-04 * va2_e_mrt
+        + -4.99204314e-05 * t2m * va2_e_mrt
+        + 2.47417178e-07 * t2m2 * va2_e_mrt
+        + 1.07596466e-08 * t2m3 * va2_e_mrt
         + 8.49242932e-05 * va3 * e_mrt
         + 1.35191328e-06 * t2m * va3 * e_mrt
         + -6.21531254e-09 * t2m2 * va3 * e_mrt
@@ -415,10 +389,10 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + -4.52166564e-07 * t2m * e_mrt2
         + 2.46688878e-08 * t2m3 * e_mrt2
         + 2.42674348e-10 * t2m4 * e_mrt2
-        + 1.54547250e-04 * va * e_mrt2
-        + 5.24110970e-06 * t2m * va * e_mrt2
-        + -8.75874982e-08 * t2m2 * va * e_mrt2
-        + -1.50743064e-09 * t2m3 * va * e_mrt2
+        + 1.54547250e-04 * va_e_mrt2
+        + 5.24110970e-06 * t2m * va_e_mrt2
+        + -8.75874982e-08 * t2m2 * va_e_mrt2
+        + -1.50743064e-09 * t2m3 * va_e_mrt2
         + -1.56236307e-05 * va2 * e_mrt2
         + -1.33895614e-07 * t2m * va2 * e_mrt2
         + 2.49709824e-09 * t2m2 * va2 * e_mrt2
@@ -430,7 +404,7 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + 7.51269482e-09 * t2m2 * e_mrt3
         + 9.79063848e-11 * t2m3 * e_mrt3
         + 1.25006734e-06 * va * e_mrt3
-        + -1.81584736e-09 * t2m * va * e_mrt3
+        + -1.81584736e-09 * t2m_va * e_mrt3
         + -3.52197671e-10 * t2m2 * va * e_mrt3
         + -3.36514630e-08 * va2 * e_mrt3
         + 1.35908359e-10 * t2m * va2 * e_mrt3
@@ -439,7 +413,7 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + 4.13908461e-10 * t2m * e_mrt4
         + 9.22652254e-12 * t2m2 * e_mrt4
         + -5.08220384e-09 * va * e_mrt4
-        + -2.24730961e-11 * t2m * va * e_mrt4
+        + -2.24730961e-11 * t2m_va * e_mrt4
         + 1.17139133e-10 * va2 * e_mrt4
         + 6.62154879e-10 * e_mrt5
         + 4.03863260e-13 * t2m * e_mrt5
@@ -451,87 +425,87 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + 9.99690870e-04 * t2m3 * rh
         + 9.51738512e-06 * t2m4 * rh
         + -4.66426341e-07 * t2m5 * rh
-        + 5.48050612e-01 * va * rh
-        + -3.30552823e-03 * t2m * va * rh
-        + -1.64119440e-03 * t2m2 * va * rh
-        + -5.16670694e-06 * t2m3 * va * rh
-        + 9.52692432e-07 * t2m4 * va * rh
-        + -4.29223622e-02 * va2 * rh
-        + 5.00845667e-03 * t2m * va2 * rh
-        + 1.00601257e-06 * t2m2 * va2 * rh
-        + -1.81748644e-06 * t2m3 * va2 * rh
+        + 5.48050612e-01 * va_rh
+        + -3.30552823e-03 * t2m * va_rh
+        + -1.64119440e-03 * t2m2 * va_rh
+        + -5.16670694e-06 * t2m3 * va_rh
+        + 9.52692432e-07 * t2m4 * va_rh
+        + -4.29223622e-02 * va2_rh
+        + 5.00845667e-03 * t2m * va2_rh
+        + 1.00601257e-06 * t2m2 * va2_rh
+        + -1.81748644e-06 * t2m3 * va2_rh
         + -1.25813502e-03 * va3 * rh
         + -1.79330391e-04 * t2m * va3 * rh
         + 2.34994441e-06 * t2m2 * va3 * rh
         + 1.29735808e-04 * va4 * rh
         + 1.29064870e-06 * t2m * va4 * rh
         + -2.28558686e-06 * va5 * rh
-        + -3.69476348e-02 * e_mrt * rh
-        + 1.62325322e-03 * t2m * e_mrt * rh
-        + -3.14279680e-05 * t2m2 * e_mrt * rh
-        + 2.59835559e-06 * t2m3 * e_mrt * rh
-        + -4.77136523e-08 * t2m4 * e_mrt * rh
-        + 8.64203390e-03 * va * e_mrt * rh
-        + -6.87405181e-04 * t2m * va * e_mrt * rh
-        + -9.13863872e-06 * t2m2 * va * e_mrt * rh
-        + 5.15916806e-07 * t2m3 * va * e_mrt * rh
-        + -3.59217476e-05 * va2 * e_mrt * rh
-        + 3.28696511e-05 * t2m * va2 * e_mrt * rh
-        + -7.10542454e-07 * t2m2 * va2 * e_mrt * rh
-        + -1.24382300e-05 * va3 * e_mrt * rh
-        + -7.38584400e-09 * t2m * va3 * e_mrt * rh
-        + 2.20609296e-07 * va4 * e_mrt * rh
-        + -7.32469180e-04 * e_mrt2 * rh
-        + -1.87381964e-05 * t2m * e_mrt2 * rh
-        + 4.80925239e-06 * t2m2 * e_mrt2 * rh
-        + -8.75492040e-08 * t2m3 * e_mrt2 * rh
-        + 2.77862930e-05 * va * e_mrt2 * rh
-        + -5.06004592e-06 * t2m * va * e_mrt2 * rh
-        + 1.14325367e-07 * t2m2 * va * e_mrt2 * rh
-        + 2.53016723e-06 * va2 * e_mrt2 * rh
-        + -1.72857035e-08 * t2m * va2 * e_mrt2 * rh
-        + -3.95079398e-08 * va3 * e_mrt2 * rh
-        + -3.59413173e-07 * e_mrt3 * rh
-        + 7.04388046e-07 * t2m * e_mrt3 * rh
-        + -1.89309167e-08 * t2m2 * e_mrt3 * rh
-        + -4.79768731e-07 * va * e_mrt3 * rh
-        + 7.96079978e-09 * t2m * va * e_mrt3 * rh
-        + 1.62897058e-09 * va2 * e_mrt3 * rh
-        + 3.94367674e-08 * e_mrt4 * rh
-        + -1.18566247e-09 * t2m * e_mrt4 * rh
-        + 3.34678041e-10 * va * e_mrt4 * rh
+        + -3.69476348e-02 * e_mrt_rh
+        + 1.62325322e-03 * t2m * e_mrt_rh
+        + -3.14279680e-05 * t2m2 * e_mrt_rh
+        + 2.59835559e-06 * t2m3 * e_mrt_rh
+        + -4.77136523e-08 * t2m4 * e_mrt_rh
+        + 8.64203390e-03 * va * e_mrt_rh
+        + -6.87405181e-04 * t2m_va * e_mrt_rh
+        + -9.13863872e-06 * t2m2 * va * e_mrt_rh
+        + 5.15916806e-07 * t2m3 * va * e_mrt_rh
+        + -3.59217476e-05 * va2 * e_mrt_rh
+        + 3.28696511e-05 * t2m * va2 * e_mrt_rh
+        + -7.10542454e-07 * t2m2 * va2 * e_mrt_rh
+        + -1.24382300e-05 * va3 * e_mrt_rh
+        + -7.38584400e-09 * t2m * va3 * e_mrt_rh
+        + 2.20609296e-07 * va4 * e_mrt_rh
+        + -7.32469180e-04 * e_mrt2_rh
+        + -1.87381964e-05 * t2m * e_mrt2_rh
+        + 4.80925239e-06 * t2m2 * e_mrt2_rh
+        + -8.75492040e-08 * t2m3 * e_mrt2_rh
+        + 2.77862930e-05 * va * e_mrt2_rh
+        + -5.06004592e-06 * t2m_va * e_mrt2_rh
+        + 1.14325367e-07 * t2m2 * va * e_mrt2_rh
+        + 2.53016723e-06 * va2 * e_mrt2_rh
+        + -1.72857035e-08 * t2m * va2 * e_mrt2_rh
+        + -3.95079398e-08 * va3 * e_mrt2_rh
+        + -3.59413173e-07 * e_mrt3_rh
+        + 7.04388046e-07 * t2m * e_mrt3_rh
+        + -1.89309167e-08 * t2m2 * e_mrt3_rh
+        + -4.79768731e-07 * va * e_mrt3_rh
+        + 7.96079978e-09 * t2m_va * e_mrt3_rh
+        + 1.62897058e-09 * va2 * e_mrt3_rh
+        + 3.94367674e-08 * e_mrt4_rh
+        + -1.18566247e-09 * t2m * e_mrt4_rh
+        + 3.34678041e-10 * va * e_mrt4_rh
         + -1.15606447e-10 * e_mrt5 * rh
         + -2.80626406e00 * rh2
         + 5.48712484e-01 * t2m * rh2
         + -3.99428410e-03 * t2m2 * rh2
         + -9.54009191e-04 * t2m3 * rh2
         + 1.93090978e-05 * t2m4 * rh2
-        + -3.08806365e-01 * va * rh2
-        + 1.16952364e-02 * t2m * va * rh2
-        + 4.95271903e-04 * t2m2 * va * rh2
-        + -1.90710882e-05 * t2m3 * va * rh2
+        + -3.08806365e-01 * varh2
+        + 1.16952364e-02 * t2m * varh2
+        + 4.95271903e-04 * t2m2 * varh2
+        + -1.90710882e-05 * t2m3 * varh2
         + 2.10787756e-03 * va2 * rh2
         + -6.98445738e-04 * t2m * va2 * rh2
         + 2.30109073e-05 * t2m2 * va2 * rh2
         + 4.17856590e-04 * va3 * rh2
         + -1.27043871e-05 * t2m * va3 * rh2
         + -3.04620472e-06 * va4 * rh2
-        + 5.14507424e-02 * e_mrt * rh2
-        + -4.32510997e-03 * t2m * e_mrt * rh2
-        + 8.99281156e-05 * t2m2 * e_mrt * rh2
-        + -7.14663943e-07 * t2m3 * e_mrt * rh2
-        + -2.66016305e-04 * va * e_mrt * rh2
-        + 2.63789586e-04 * t2m * va * e_mrt * rh2
-        + -7.01199003e-06 * t2m2 * va * e_mrt * rh2
-        + -1.06823306e-04 * va2 * e_mrt * rh2
-        + 3.61341136e-06 * t2m * va2 * e_mrt * rh2
-        + 2.29748967e-07 * va3 * e_mrt * rh2
-        + 3.04788893e-04 * e_mrt2 * rh2
-        + -6.42070836e-05 * t2m * e_mrt2 * rh2
-        + 1.16257971e-06 * t2m2 * e_mrt2 * rh2
-        + 7.68023384e-06 * va * e_mrt2 * rh2
-        + -5.47446896e-07 * t2m * va * e_mrt2 * rh2
-        + -3.59937910e-08 * va2 * e_mrt2 * rh2
+        + 5.14507424e-02 * e_mrt_rh2
+        + -4.32510997e-03 * t2m * e_mrt_rh2
+        + 8.99281156e-05 * t2m2 * e_mrt_rh2
+        + -7.14663943e-07 * t2m3 * e_mrt_rh2
+        + -2.66016305e-04 * va * e_mrt_rh2
+        + 2.63789586e-04 * t2m_va * e_mrt_rh2
+        + -7.01199003e-06 * t2m2 * va * e_mrt_rh2
+        + -1.06823306e-04 * va2 * e_mrt_rh2
+        + 3.61341136e-06 * t2m * va2 * e_mrt_rh2
+        + 2.29748967e-07 * va3 * e_mrt_rh2
+        + 3.04788893e-04 * e_mrt2_rh2
+        + -6.42070836e-05 * t2m * e_mrt2_rh2
+        + 1.16257971e-06 * t2m2 * e_mrt2_rh2
+        + 7.68023384e-06 * va * e_mrt2_rh2
+        + -5.47446896e-07 * t2m_va * e_mrt2_rh2
+        + -3.59937910e-08 * va2 * e_mrt2_rh2
         + -4.36497725e-06 * e_mrt3 * rh2
         + 1.68737969e-07 * t2m * e_mrt3 * rh2
         + 2.67489271e-08 * va * e_mrt3 * rh2
@@ -541,17 +515,17 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + 1.55126038e-02 * t2m2 * rh3
         + -2.63917279e-04 * t2m3 * rh3
         + 4.53433455e-02 * va * rh3
-        + -4.32943862e-03 * t2m * va * rh3
+        + -4.32943862e-03 * t2m_va * rh3
         + 1.45389826e-04 * t2m2 * va * rh3
         + 2.17508610e-04 * va2 * rh3
         + -6.66724702e-05 * t2m * va2 * rh3
         + 3.33217140e-05 * va3 * rh3
-        + -2.26921615e-03 * e_mrt * rh3
-        + 3.80261982e-04 * t2m * e_mrt * rh3
-        + -5.45314314e-09 * t2m2 * e_mrt * rh3
-        + -7.96355448e-04 * va * e_mrt * rh3
-        + 2.53458034e-05 * t2m * va * e_mrt * rh3
-        + -6.31223658e-06 * va2 * e_mrt * rh3
+        + -2.26921615e-03 * e_mrt_rh3
+        + 3.80261982e-04 * t2m * e_mrt_rh3
+        + -5.45314314e-09 * t2m2 * e_mrt_rh3
+        + -7.96355448e-04 * va * e_mrt_rh3
+        + 2.53458034e-05 * t2m_va * e_mrt_rh3
+        + -6.31223658e-06 * va2 * e_mrt_rh3
         + 3.02122035e-04 * e_mrt2 * rh3
         + -4.77403547e-06 * t2m * e_mrt2 * rh3
         + 1.73825715e-06 * va * e_mrt2 * rh3
@@ -560,7 +534,7 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + -6.16755931e-02 * t2m * rh4
         + 1.33374846e-03 * t2m2 * rh4
         + 3.55375387e-03 * va * rh4
-        + -5.13027851e-04 * t2m * va * rh4
+        + -5.13027851e-04 * t2m_va * rh4
         + 1.02449757e-04 * va2 * rh4
         + -1.48526421e-03 * e_mrt * rh4
         + -4.11469183e-05 * t2m * e_mrt * rh4
@@ -573,37 +547,45 @@ def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
         + 1.48348065e-03 * rh6
     )
 
-    # print(f"utci {utci}")
+    return utci
 
-    # utci_filtert2m = np.where(t2m >= 70)
-    # utci[utci_filtert2m] = -9999
-    # print(f"utci f1 {utci}")
 
-    # utci_filtert2m2 = np.where(t2m <= -70)
-    # utci[utci_filtert2m2] = -9999
-    # print(f"utci f2 {utci}")
+def calculate_utci(t2_k, va_ms, mrt_k, e_hPa=None, td_k=None):
+    """
+    UTCI
+    :param t2_k: (float array) is 2m temperature [K]
+    :param va_ms: (float array) is wind speed at 10 meters [m/s]
+    :param mrt_k:(float array) is mean radiant temperature [K]
+    :param e_hPa: (float array) is water vapour pressure [hPa]
+    :param td_k: (float array) is 2m dew point temperature [K]
 
-    # utci_filterva = np.where(17 <= va)
-    # utci[utci_filterva] = -9999
-    # print(f"utci f3 {utci}")
+    Calculate UTCI with a 6th order polynomial approximation according to:
+    Brode, P. et al. Deriving the operational procedure for the
+    Universal Thermal Climate Index (UTCI). Int J Biometeorol (2012) 56: 48.1
 
-    # utci_filterva2 = np.where(0 >= va)
-    # utci[utci_filterva2] = -9999
-    # print(f"utci f4 {utci}")
+    returns UTCI [°C]
 
-    # utci_filterrh = np.where(5 < rh)
-    # utci[utci_filterrh] = -9999
-    # print(f"utci f5 {utci}")
+    """
+    t2 = __wrap(t2_k)
+    va = __wrap(va_ms)
+    mrt_kw = __wrap(mrt_k)
 
-    # utci_filtere_mrt = np.where(e_mrt >= 100.0)
-    # utci[utci_filtere_mrt] = -9999
-    # print(f"utci f6 {utci}")
+    if e_hPa is not None:
+        ehPa = __wrap(e_hPa)
+        rh = ehPa / 10.0  # rh in kPa
+    else:
+        if td_k is not None:
+            t2d = __wrap(td_k)
+            rh_pc = calculate_relative_humidity_percent(t2, t2d)
+            ehPa = calculate_saturation_vapour_pressure(t2) * rh_pc / 100.0
+            rh = ehPa / 10.0  # rh in kPa
+        else:
+            raise ValueError("Missing input e_hPa or td_k")
 
-    # utci_filtere_mrt2 = np.where(e_mrt <= -30)
-    # utci[utci_filtere_mrt2] = -9999
-    # print(f"utci f7 {utci}")
+    t2m = kelvin_to_celsius(t2)  # polynomial approx. is in Celsius
+    mrt = kelvin_to_celsius(mrt_kw)  # polynomial approx. is in Celsius
 
-    # print(f"utci {utci}")
+    utci = calculate_utci_impl(t2m, mrt, va, rh)
 
     return utci
 
